/*! Slugify - v0.1.0 - 2013-05-22
* https://github.com/madflow/jquery-slugify
* Copyright (c) 2013 madflow; Licensed MIT */
;(function($) {

    $.fn.slugify = function(source, options) {
        return this.each(function() {
            var $target = $(this),
                $source = $(source);
                
            $target.on('keyup change',function() {
                if($target.val() !== '' && $target.val() !== undefined) {
                    $target.data('locked', true);
                } else {
                    $target.data('locked', false);
                }
            });

            $source.on('keyup change',function() {
                if( true === $target.data('locked')) {return;}
                if($target.is('input') || $target.is('textarea')) {
                    $target.val($.slugify($source.val(), options));
                } else {
                    $target.text($.slugify($source.val(), options));
                }
            });
        });
    };

    // Static method.
    $.slugify = function(sourceString, options) {
        // Override default options with passed-in options.
        options = $.extend({}, $.slugify.options, options);
        sourceString = $.trim(sourceString); // Trim
        sourceString = sourceString.toLowerCase();  // Lower Case
        $.each(options.replaceMap, function(key, value) { // Special char map
            sourceString = sourceString.replace(new RegExp(key, 'g'), value || options.invalid);
        });
        return sourceString
                .replace(/\s+/g, options.whitespace) // Replace whitespace characters
                .replace(new RegExp('[^a-z0-9 '+ options.whitespace +']', 'g'), options.invalid); // Replace invalid characters
    };

    // Default options
    $.slugify.options = {
        whitespace: '-',
        invalid: '',
        replaceMap: {
                'Ã¡': 'a',
                'Ã ': 'a',
                'Ã¢': 'a',
                'Ã¤': 'ae',
                'Ã£': 'a',
                'Ã¦': 'ae',
                'Ã§': 'c',
                'Ã©': 'e',
                'Ã¨': 'e',
                'Ãª': 'e',
                'Ã«': 'e',
                'áº½': 'e',
                'Ã­': 'i',
                'Ã¬': 'i',
                'Ã®': 'i',
                'Ã¯': 'i',
                'Ä©': 'i',
                'Ã³': 'o',
                'Ã²': 'o',
                'Ã´': 'o',
                'Ã¶': 'oe',
                'Ãµ': 'o',
                'Å“': 'oe',
                'ÃŸ': 'ss',
                'Ãº': 'u',
                'Ã¹': 'u',
                'Ã»': 'u',
                'Ã¼': 'ue',
                'Å©': 'u',
                'Äƒ': 'a',
                'áº¯': 'a',
                'áº±': 'a',
                'áºµ': 'a',
                'áº³': 'a',
                'áº¥': 'a',
                'áº§': 'a',
                'áº«': 'a',
                'áº©': 'a',
                'ÇŽ': 'a',
                'Ã¥': 'a',
                'Ç»': 'a',
                'ÇŸ': 'a',
                'È§': 'a',
                'Ç¡': 'a',
                'Ä…': 'a',
                'Ä': 'a',
                'áº£': 'a',
                'È': 'a',
                'Èƒ': 'a',
                'áº¡': 'a',
                'áº·': 'a',
                'áº­': 'a',
                'á¸': 'a',
                'â±¥': 'a',
                'á¶': 'a',
                'É': 'a',
                'É‘': 'a',
                'á¸ƒ': 'b',
                'á¸…': 'b',
                'á¸‡': 'b',
                'Æ€': 'b',
                'É“': 'b',
                'Æƒ': 'b',
                'áµ¬': 'b',
                'á¶€': 'b',
                'Ã¾': 'b',
                'Ä‡': 'c',
                'Ä‰': 'c',
                'Ä': 'c',
                'Ä‹': 'c',
                'á¸‰': 'c',
                'È¼': 'c',
                'Æˆ': 'c',
                'É•': 'c',
                'Ä': 'd',
                'á¸‹': 'd',
                'á¸‘': 'd',
                'á¸': 'd',
                'á¸“': 'd',
                'á¸': 'd',
                'Ä‘': 'd',
                'É–': 'd',
                'É—': 'd',
                'ÆŒ': 'd',
                'áµ­': 'd',
                'á¶': 'd',
                'á¶‘': 'd',
                'È¡': 'd',
                'âˆ‚': 'd',
                'Ä•': 'e',
                'áº¿': 'e',
                'á»': 'e',
                'á»…': 'e',
                'á»ƒ': 'e',
                'Ä›': 'e',
                'Ä—': 'e',
                'È©': 'e',
                'á¸': 'e',
                'Ä™': 'e',
                'Ä“': 'e',
                'á¸—': 'e',
                'á¸•': 'e',
                'áº»': 'e',
                'È…': 'e',
                'È‡': 'e',
                'áº¹': 'e',
                'á»‡': 'e',
                'á¸™': 'e',
                'á¸›': 'e',
                'É‡': 'e',
                'á¶’': 'e',  
                'á¸Ÿ': 'f',
                'Æ’': 'f',
                'áµ®': 'f',
                'á¶‚': 'f', 
                'Çµ': 'g',
                'ÄŸ': 'g',
                'Ä': 'g',
                'Ç§': 'g',
                'Ä¡': 'g',
                'Ä£': 'g',
                'á¸¡': 'g',
                'Ç¥': 'g',
                'É ': 'g',
                'á¶ƒ': 'g',
                'Ä¥': 'h',
                'ÈŸ': 'h',
                'á¸§': 'h',
                'á¸£': 'h',
                'á¸©': 'h',
                'á¸¥': 'h',
                'á¸«': 'h',
                'áº–': 'h',
                'Ä§': 'h',
                'â±¨': 'h',
                'Ä­': 'i',
                'Ç': 'i',
                'á¸¯': 'i',
                'Ä¯': 'i',
                'Ä«': 'i',
                'á»‰': 'i',
                'È‰': 'i',
                'È‹': 'i',
                'á»‹': 'i',
                'á¸­': 'i',
                'É¨': 'i',
                'áµ»': 'i',
                'á¶–': 'i',
                'i': 'i',
                'Ä±': 'i', 
                'Äµ': 'j',
                'É‰': 'j',
                'Ç°': 'j',
                'È·': 'j',
                'Ê': 'j',
                'ÉŸ': 'j',
                'Ê„': 'j',
                'á¸±': 'k',
                'Ç©': 'k',
                'Ä·': 'k',
                'á¸³': 'k',
                'á¸µ': 'k',
                'Æ™': 'k',
                'â±ª': 'k',
                'á¶„': 'k',
                'Äº': 'l',
                'Ä¾': 'l',
                'Ä¼': 'l',
                'á¸·': 'l',
                'á¸¹': 'l',
                'á¸½': 'l',
                'á¸»': 'l',
                'Å‚': 'l',
                'Å€': 'l',
                'Æš': 'l',
                'â±¡': 'l',
                'É«': 'l',
                'É¬': 'l',
                'á¶…': 'l',
                'É­': 'l',
                'È´': 'l',
                'á¸¿': 'm',
                'á¹': 'm',
                'á¹ƒ': 'm',
                'áµ¯': 'm',
                'á¶†': 'm',
                'É±': 'm',
                
                'Å„': 'n',
                'Ç¹': 'n',
                'Åˆ': 'n',
                'Ã±': 'n',
                'á¹…': 'n',
                'Å†': 'n',
                'á¹‡': 'n',
                'á¹‹': 'n',
                'á¹‰': 'n',
                'nÌˆ': 'n',
                'É²': 'n',
                'Æž': 'n',
                'Å‹': 'n',
                'áµ°': 'n',
                'á¶‡': 'n',
                'É³': 'n',
                'Èµ': 'n',
                'Å': 'o',
                'á»‘': 'o',
                'á»“': 'o',
                'á»—': 'o',
                'á»•': 'o',
                'Ç’': 'o',
                'È«': 'o',
                'Å‘': 'o',
                'á¹': 'o',
                'á¹': 'o',
                'È­': 'o',
                'È¯': 'o',
                'Í˜oÍ˜': 'o',
                'È±': 'o',
                'Ã¸': 'o',
                'Ç¿': 'o',
                'Ç«': 'o',
                'Ç­': 'o',
                'Å': 'o',
                'á¹“': 'o',
                'á¹‘': 'o',
                'á»': 'o',
                'È': 'o',
                'È': 'o',
                'Æ¡': 'o',
                'á»›': 'o',
                'á»': 'o',
                'á»¡': 'o',
                'á»Ÿ': 'o',
                'á»£': 'o',
                'á»': 'o',
                'á»™': 'o',
                'Éµ': 'o',
                'É”': 'o',
                'á¹•': 'p',
                'á¹—': 'p',
                'áµ½': 'p',
                'Æ¥': 'p',
                'pÌƒ': 'p',
                'áµ±': 'p',
                'á¶ˆ': 'p',
                'É‹': 'q',
                'Æ£': 'q',
                'Ê ': 'q',      
                'Å•': 'r',
                'Å™': 'r',
                'á¹™': 'r',
                'Å—': 'r',
                'È‘': 'r',
                'È“': 'r',
                'á¹›': 'r',
                'á¹': 'r',
                'á¹Ÿ': 'r',
                'É': 'r',
                'É½': 'r',
                'áµ²': 'r',
                'á¶‰': 'r',
                'É¼': 'r',
                'É¾': 'r',
                'áµ³': 'r',
                'Å›': 's',
                'á¹¥': 's',
                'Å': 's',
                'Å¡': 's',
                'á¹§': 's',
                'á¹¡áº›': 's',
                'ÅŸ': 's',
                'á¹£': 's',
                'á¹©': 's',
                'È™': 's',
                'sÌ©': 's',
                'áµ´': 's',
                'á¶Š': 's',
                'Ê‚': 's',
                'È¿': 's',
                'Å¥': 't',
                'á¹«': 't',
                'Å£': 't',
                'á¹­': 't',
                'È›': 't',
                'á¹±': 't',
                'á¹¯': 't',
                'Å§': 't',
                'â±¦': 't',
                'Æ­': 't',
                'Êˆ': 't',
                'Ìˆáº—': 't',
                'áµµ': 't',
                'Æ«': 't',
                'È¶': 't',
                'Å­': 'u',
                'Ç”': 'u',
                'Å¯': 'u',
                'Ç˜': 'u',
                'Çœ': 'u',
                'Çš': 'u',
                'Ç–': 'u',
                'Å±': 'u',
                'á¹¹': 'u',
                'Å³': 'u',
                'Å«': 'u',
                'á¹»': 'u',
                'á»§': 'u',
                'È•': 'u',
                'È—': 'u',
                'Æ°': 'u',
                'á»©': 'u',
                'á»«': 'u',
                'á»¯': 'u',
                'á»­': 'u',
                'á»±': 'u',
                'á»¥': 'u',
                'á¹³': 'u',
                'á¹·': 'u',
                'á¹µ': 'u',
                'Ê‰': 'u',
                'áµ¾': 'u',
                'á¶™': 'u',
                'á¹½': 'v',
                'á¹¿': 'v',
                'Ê‹': 'v',
                'á¶Œ': 'v',
                'â±´': 'v',
                'áºƒ': 'w',
                'áº': 'w',
                'Åµ': 'w',
                'áº…': 'w',
                'áº‡': 'w',
                'áº‰': 'w',
                'áº˜': 'w',
                'áº': 'x',
                'áº‹': 'x',
                'á¶': 'x',   
                'Ã½': 'y',
                'á»³': 'y',
                'Å·': 'y',
                'áº™': 'y',
                'Ã¿': 'y',
                'á»¹': 'y',
                'áº': 'y',
                'È³': 'y',
                'á»·': 'y',
                'á»µ': 'y',
                'É': 'y',
                'Æ´': 'y',
                'Ê': 'y',
                'Åº': 'z',
                'áº‘': 'z',
                'Å¾': 'z',
                'Å¼': 'z',
                'áº“': 'z',
                'áº•': 'z',
                'Æ¶': 'z',
                'È¥': 'z',
                'â±¬': 'z',
                'áµ¶': 'z',
                'á¶Ž': 'z',
                'Ê': 'z',
                'Ê‘': 'z',
                'É€': 'z',
                'Î±': 'a',
                'Î²': 'b',
                'Î³': 'g',
                'É£': 'g',
                'Î´': 'd',
                'Ã°': 'd',
                'Îµ': 'e',
                'Î¶': 'z',
                'Î·': 'i',
                'Î¸': 'th',
                'Î¹': 'i',
                'Îº': 'k',
                'Î»': 'l',
                'Î¼': 'm',
                'Âµ': 'm',
                'Î½': 'n',
                'Î¾': 'x',
                'Î¿': 'o',
                'Ï€': 'p',
                'Ï': 'r',
                'Ïƒ': 's',
                'Ï‚': 's',
                'Ï„': 't',
                'Ï…': 'u',
                'Ï†': 'f',
                'Ï‡': 'ch',
                'Ïˆ': 'ps',
                'Ï‰': 'o',
                'á¾³': 'a',
                'Î¬': 'a',
                'á½°': 'a',
                'á¾´': 'a',
                'á¾²': 'a',
                'á¾¶': 'a',
                'á¾·': 'a',
                'á¼€': 'a',
                'á¾€': 'a',
                'á¼„': 'a',
                'á¾„': 'a',
                'á¼‚': 'a',
                'á¾‚': 'a',
                'á¼†': 'a',
                'á¾†': 'a',
                'á¼': 'a',
                'á¾': 'a',
                'á¼…': 'a',
                'á¾…': 'a',
                'á¼ƒ': 'a',
                'á¾ƒ': 'a',
                'á¼‡': 'a',
                'á¾‡': 'a',
                'á¾±': 'a',
                'á¾°': 'a',
                'Î­': 'e',
                'á½²': 'e',
                'á¼': 'e',
                'á¼”': 'e',
                'á¼’': 'e',
                'á¼‘': 'e',
                'á¼•': 'e',
                'á¼“': 'e',
                'á¿ƒ': 'i',
                'Î®': 'i',
                'á½´': 'i',
                'á¿„': 'i',
                'á¿‚': 'i',
                'á¿†': 'i',
                'á¿‡': 'i',
                'á¼ ': 'i',
                'á¾': 'i',
                'á¼¤': 'i',
                'á¾”': 'i',
                'á¼¢': 'i',
                'á¾’': 'i',
                'á¼¦': 'i',
                'á¾–': 'i',
                'á¼¡': 'i',
                'á¾‘': 'i',
                'á¼¥': 'i',
                'á¾•': 'i',
                'á¼£': 'i',
                'á¾“': 'i',
                'á¼§': 'i',
                'á¾—': 'i',
                'Î¯': 'i',
                'á½¶': 'i',
                'á¿–': 'i',
                'á¼°': 'i',
                'á¼´': 'i',
                'á¼²': 'i',
                'á¼¶': 'i',
                'á¼±': 'i',
                'á¼µ': 'i',
                'á¼³': 'i',
                'á¼·': 'i',
                'ÏŠ': 'i',
                'Î': 'i',
                'á¿’': 'i',
                'á¿—': 'i',
                'á¿‘': 'i',
                'á¿': 'i',
                'ÏŒ': 'o',
                'á½¸': 'o',
                'á½€': 'o',
                'á½„': 'o',
                'á½‚': 'o',
                'á½': 'o',
                'á½…': 'o',
                'á½ƒ': 'o',
                'Ï': 'u',
                'á½º': 'u',
                'á¿¦': 'u',
                'á½': 'u',
                'á½”': 'u',
                'á½’': 'u',
                'á½–': 'u',
                'á½‘': 'u',
                'á½•': 'u',
                'á½“': 'u',
                'á½—': 'u',
                'Ï‹': 'u',
                'Î°': 'u',
                'á¿¢': 'u',
                'á¿§': 'u',
                'á¿¡': 'u',
                'á¿ ': 'u',
                'á¿³': 'o',
                'ÏŽ': 'o',
                'á¿´': 'o',
                'á½¼': 'o',
                'á¿²': 'o',
                'á¿¶': 'o',
                'á¿·': 'o',
                'á½ ': 'o',
                'á¾ ': 'o',
                'á½¤': 'o',
                'á¾¤': 'o',
                'á½¢': 'o',
                'á¾¢': 'o',
                'á½¦': 'o',
                'á¾¦': 'o',
                'á½¡': 'o',
                'á¾¡': 'o',
                'á½¥': 'o',
                'á¾¥': 'o',
                'á½£': 'o',
                'á¾£': 'o',
                'á½§': 'o',
                'á¾§': 'o',
                'á¿¤': 'r',
                'á¿¥': 'r',
                'Ð°': 'a',
                'Ð±': 'b',
                'Ð²': 'v',
                'Ð³': 'g',
                'Ð´': 'd',
                'Ðµ': 'e',
                'Ñ‘': 'e',
                'Ð¶': 'zh',
                'Ð·': 'z',
                'Ð¸': 'i',
                'Ð¹': 'j',
                'Ðº': 'k',
                'Ð»': 'l',
                'Ð¼': 'm',
                'Ð½': 'n',
                'Ð¾': 'o',
                'Ð¿': 'p',
                'Ñ€': 'r',
                'Ñ': 's',
                'Ñ‚': 't',
                'Ñƒ': 'u',
                'Ñ„': 'f',
                'Ñ…': 'h',
                'Ñ†': 'ts',
                'Ñ‡': 'ch',
                'Ñˆ': 'sh',
                'Ñ‰': 'sh',
                'ÑŠ': '',
                'Ñ‹': 'i',
                'ÑŒ': '',
                'Ñ': 'e',
                'ÑŽ': 'yu',
                'Ñ': 'ya',
                'Ñ–': 'j',
                'Ñ³': 'f',
                'Ñ£': 'e',
                'Ñµ': 'i',
                'Ñ•': 'z',
                'Ñ¯': 'ks',
                'Ñ±': 'ps',
                'Ñ¡': 'o',
                'Ñ«': 'yu',
                'Ñ§': 'ya',
                'Ñ­': 'yu',
                'Ñ©': 'ya'
        }
    };
    
}(jQuery));